# Copyright (C) 2020-2023 Koen Derks

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

context("Validation of other functionality")

# jfa version 0.5.0

test_that(desc = "(id: f4-v0.5.0-t1) Function test .markdown_call()", {
  testthat::skip_on_cran()
  x <- .markdown_call("rmarkdown::render")
  expect_equal(length(x), 1)
})
